@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-wget",
-    "1.0.430",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-lambda-layer-wget@1.0.430.jsii.tgz",
+    "cdk-lambda-layer-wget@2.0.0.jsii.tgz",
 )
 
 __all__ = [
